@@ -1209,7 +1209,7 @@ err:
 }
 EXPORT_SYMBOL(ddcci_device_writeread);
 
-#define IS_ANY_ID(x) (((x)[0] == -1) && ((x)[7] == -1))
+#define IS_ANY_ID(x) (((x)[0] == '\xFF') && ((x)[7] == '\xFF'))
 
 /* Check if any device id in the array matches the device and return the matching id */
 static const struct ddcci_device_id *ddcci_match_id(const struct ddcci_device_id *id,
@@ -1785,6 +1785,13 @@ static int ddcci_remove(struct i2c_client *client)
 	return 0;
 }
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 1, 0)
+static void ddcci_remove_void(struct i2c_client *client)
+{
+	ddcci_remove(client);
+}
+#endif
+
 /*
  * I2C driver device identification table.
  */
@@ -1806,7 +1813,11 @@ static struct i2c_driver ddcci_driver = {
 
 	.id_table	= ddcci_idtable,
 	.probe		= ddcci_probe,
+	#if LINUX_VERSION_CODE >= KERNEL_VERSION(6, 1, 0)
+	.remove		= ddcci_remove_void,
+	#else
 	.remove		= ddcci_remove,
+	#endif
 	.class		= I2C_CLASS_DDC,
 	.detect		= ddcci_detect,
 	.address_list	= I2C_ADDRS(
@@ -1891,5 +1902,5 @@ MODULE_PARM_DESC(autoprobe_addrs, "internal dependent device addresses to autopr
 /* Module description */
 MODULE_AUTHOR("Christoph Grenz");
 MODULE_DESCRIPTION("DDC/CI bus driver");
-MODULE_VERSION("0.4.2");
+MODULE_VERSION("0.4.3");
 MODULE_LICENSE("GPL");
